<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tns="http://www.oasis-open.org/tc/ebxml-iic/conformance/reqs">
	<xsl:output method="html"/>
	<!--  
Copyright (C) The Organization for the Advancement of Structured Information Standards [OASIS] 
January 2002. All Rights Reserved.
This document and translations of it may be copied and furnished to others, and derivative works that comment on or otherwise explain it or assist in its implementation may be prepared, copied, published and distributed, in whole or in part, without restriction of any kind, provided that the above copyright notice and this paragraph are included on all such copies and derivative works. However, this document itself may not be modified in any way, such as by removing the copyright notice or references to OASIS, except as needed for the purpose of developing OASIS specifications, in which case the procedures for copyrights defined in the OASIS Intellectual Property Rights document MUST be followed, or as required to translate it into languages other than English.
The limited permissions granted above are perpetual and will not be revoked by OASIS or its successors or assigns.
-->
	<!-- OASIS/ebXML Test Suite Framework
	       Description: XSLT Style Sheet for transforming ebXML testing requirements to HTML format
	       $Author: Michael Kass $
	       Organization: NIST
	       Date: 05/14/2003
	        -->
	<xsl:template match="/">
		<html>
			<head>
				<title>OASIS ebxml-iic TC -> Requirements</title>
				<style>
	            body  { font-family: Arial, Helvetica, Sans-Serif; font-size: small }
	            h1    { font-size: large }
	            th    { border: thin solid }        
	            td    { border: thin solid; font-size: x-small }
	            .recommended { font-color: #008800 }
	            .strongly_recommended { font-color: #008800 }
	            .optional { font-color: #000000 }
	            .required { font-color: #000000 }    
	            .testreq_id_cell  { background: #C0C0C0; font-weight: bold }
	            .id_cell  {font-weight: bold }
	        </style>
			</head>
			<body>
				<xsl:apply-templates/>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="tns:MetaData">
		<h2>
			<xsl:value-of select="tns:Description"/>
		</h2>
	</xsl:template>
	<xsl:template match="tns:Requirements">
		<table border="0">
			<tr>
				<th>ID</th>
				<th>Name</th>
				<th>Specification Ref</th>
				<th>Precondition</th>
				<th>Requirement Level</th>
				<th>Assertion</th>
			</tr>
			<xsl:apply-templates/>
		</table>
	</xsl:template>
	<xsl:template match="Level">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="tns:TestRequirement">
				<tr>
			<td class="testreq_id_cell">
				<xsl:value-of select="@id"/>
			</td>
			<td>
				<xsl:value-of select="@name"/>
			</td>
			<td>
				<xsl:value-of select="@specRef"/>
			</td>
			<xsl:choose>
				<xsl:when test="tns:Clause">
					<td>
						<xsl:apply-templates/>
					</td>
				</xsl:when>
				<xsl:otherwise>
					<td/>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</tr>	</xsl:template>
	<xsl:template match="tns:FunctionalRequirement">
		<tr>
			<td class="id_cell">
				<xsl:value-of select="@id"/>
			</td>
			<td>
				<xsl:value-of select="@name"/>
			</td>
			<td>
				<xsl:value-of select="@specRef"/>
			</td>
			<xsl:choose>
				<xsl:when test="tns:Clause">
					<td>
						<xsl:apply-templates/>
					</td>
				</xsl:when>
				<xsl:otherwise>
					<td/>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</tr>
	</xsl:template>
	<xsl:template match="tns:Condition">
				<span class="required">
					<xsl:value-of select="."/>
				</span>
			</xsl:template>
	<xsl:template match="tns:Assertion">
		<xsl:choose>
			<xsl:when test="@requirementType='required'">
				<td>REQUIRED</td>
				<td>
					<xsl:value-of select="."/>
				</td>
			</xsl:when>
			<xsl:when test="@requirementType='strongly recommended'">
				<td>STRONGLY RECOMMENDED</td>
				<td bgcolor="00BB00">
					<xsl:value-of select="."/>
				</td>
			</xsl:when>
			<xsl:when test="@requirementType='recommended'">
				<td>RECOMMENDED</td>
				<td bgcolor="00BB00">
					<xsl:value-of select="."/>
				</td>
			</xsl:when>
			<xsl:when test="@requirementType='optional'">
				<td>OPTIONAL</td>
				<td bgcolor="00BB00">
					<xsl:value-of select="."/>
				</td>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="tns:Clause">
		<b>(</b>
		<xsl:apply-templates/>
		<b>)</b>
	</xsl:template>
	<xsl:template match="tns:And">
		<xsl:text> AND </xsl:text>
	</xsl:template>
	<xsl:template match="tns:Or">
		<xsl:text> OR </xsl:text>
	</xsl:template>
</xsl:stylesheet>
