<?xml version="1.0" encoding="UTF-8"?>
<!-- 
Copyright (C) The Organization for the Advancement of Structured Information Standards [OASIS] 
January 2002. All Rights Reserved.
This document and translations of it may be copied and furnished to others, and derivative works that comment on or otherwise explain it or assist in its implementation may be prepared, copied, published and distributed, in whole or in part, without restriction of any kind, provided that the above copyright notice and this paragraph are included on all such copies and derivative works. However, this document itself may not be modified in any way, such as by removing the copyright notice or references to OASIS, except as needed for the purpose of developing OASIS specifications, in which case the procedures for copyrights defined in the OASIS Intellectual Property Rights document MUST be followed, or as required to translate it into languages other than English.
The limited permissions granted above are perpetual and will not be revoked by OASIS or its successors or assigns.
-->
<!-- OASIS/ebXML Test Suite Framework
	       Description: XSLT Style Sheet for transforming ebXML test suites to HTML format
	       $Author: Michael Kass $
	       Organization: NIST
	       Date: 05/14/2003
	        -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:ebTest="http://www.oasis-open.org/tc/ebxml-iic/tests">
	<xsl:import href="xmlverbatimwrapper.xsl"/>
	<xsl:output method="html"/>
	<xsl:template match="/">
		<head>
			<title>ebXML Test Suite
	       Author: Michael Kass
	       Organization: NIST
	       Date: 05/15/2003
	       Version 1.0
</title>
			<link rel="stylesheet" type="text/css" href="xmlverbatim.css"/>
		</head>
		<xsl:apply-templates select="ebTest:TestSuite/ebTest:MetaData"/>
		<table border="2">
			<xsl:apply-templates select="ebTest:TestSuite"/>
		</table>
	</xsl:template>
	<xsl:template match="ebTest:MetaData">
		<center>
			<h2>
				<xsl:value-of select="ebTest:Description"/>
			</h2>
		</center>
	</xsl:template>
	<xsl:template match="ebTest:TestSuite">
		<tr>
			<td width="10%" align="center">
				<h4>Test Object</h4>
			</td>
			<td width="10%" align="center">
				<h4>ID</h4>
			</td>
			<td width="10%" align="center">
				<h4>Description</h4>
			</td>
			<td width="10%" align="center">
				<h4>Mode</h4>
			</td>
			<td width="10%" align="center">
				<h4>Operation</h4>
			</td>
			<td width="10%" align="center">
				<h4>Configuration</h4>
			</td>
			<td width="40%" align="center">
				<h4>Message Expression</h4>
			</td>
		</tr>
		<tr>
			<td width="10%" align="left">Test Suite</td>
			<td width="10%" align="center"/>
			<td width="10%" align="center"/>
			<td width="10%" align="center"/>
			<td width="10%" align="center"/>
			<td width="10%" align="left">
				<xsl:if test="@ebTest:configurationGroupRef">
					<xsl:variable name="refId">
						<xsl:value-of select="@ebTest:configurationGroupRef"/>
					</xsl:variable>
					<xsl:apply-templates select="ebTest:ConfigurationGroup[@ebTest:id=$refId]"/>
				</xsl:if>
			</td>
			<td width="40%" align="center"/>
		</tr>
		<xsl:apply-templates select="ebTest:TestCase"/>
	</xsl:template>
	<xsl:template match="ebTest:ConfigurationGroup">
		<b>
			<center>
				<h4>
					<xsl:value-of select="@ebTest:actionType"/>
				</h4>
			</center>
			<xsl:if test="ebTest:Mode">Mode = <xsl:value-of select="ebTest:Mode"/>
				<br/>
			</xsl:if>
			<xsl:if test="ebTest:CPAId">CPAId = <xsl:value-of select="ebTest:CPAId"/>
				<br/>
			</xsl:if>
			<xsl:if test="ebTest:ResponseURL">ResponseURL = <xsl:value-of select="ebTest:ResponseURL"/>
				<br/>
			</xsl:if>
			<xsl:if test="ebTest:Service">Service = <xsl:value-of select="ebTest:Service"/>
				<br/>
			</xsl:if>
			<xsl:if test="ebTest:Action">Action = <xsl:value-of select="ebTest:Action"/>
				<br/>
			</xsl:if>
			<xsl:if test="ebTest:SenderParty">SenderParty = <xsl:value-of select="ebTest:SenderParty"/>
				<br/>
			</xsl:if>
			<xsl:if test="ebTest:ReceiverParty">ReceiverParty = <xsl:value-of select="ebTest:ReceiverParty"/>
				<br/>
			</xsl:if>
			<xsl:if test="ebTest:PayloadDigests">
				<xsl:apply-templates select="ebTest:PayloadDigests"/>
				<br/>
			</xsl:if>
			<xsl:if test="ebTest:ConfigurationItem">
				<xsl:apply-templates select="ConfigurationItem"/>
				<br/>
			</xsl:if>
		</b>
	</xsl:template>
	<xsl:template match="ebTest:PayloadDigests">
		<xsl:apply-templates select="ebTest:Payload"/>
	</xsl:template>
	<xsl:template match="ebTest:Payload">
		<xsl:value-of select="ebTest:Href"/>=<xsl:value-of select="ebTest:Digest"/>
		<br/>
	</xsl:template>
	<xsl:template match="ebTest:TestCase">
		<tr>
			<td>
				<b>	Test Case </b>
			</td>
			<td>
				<i>
					<b>
						<xsl:value-of select="@ebTest:id"/>
					</b>
				</i>
			</td>
			<td>
				<i>
					<b>
						<xsl:value-of select="@ebTest:description"/>
					</b>
				</i>
			</td>
			<td/>
			<td/>
			<td>
				<xsl:if test="@ebTest:configurationGroupRef">
					<xsl:variable name="refId">
						<xsl:value-of select="@ebTest:configurationGroupRef"/>
					</xsl:variable>
					<xsl:apply-templates select="../ebTest:ConfigurationGroup[@ebTest:id=$refId]"/>
				</xsl:if>
			</td>
			<td/>
		</tr>
		<xsl:apply-templates select="ebTest:TestStep"/>
	</xsl:template>
	<xsl:template match="ebTest:TestStep">
		<tr>
			<td>TestStep</td>
			<td>
				<xsl:value-of select="position()"/>
			</td>
			<td>
				<xsl:value-of select="@ebTest:description"/>
			</td>
			<td>
				<xsl:value-of select="@ebTest:mode"/>
			</td>
			<td/>
			<td>
				<xsl:if test="@ebTest:configurationGroupRef">
					<xsl:variable name="refId">
						<xsl:value-of select="@ebTest:configurationGroupRef"/>
					</xsl:variable>
					<xsl:apply-templates select="../../ebTest:ConfigurationGroup[@ebTest:id=$refId]"/>
				</xsl:if>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:PutMessage|ebTest:GetMessage"/>
	</xsl:template>
	<xsl:template match="ebTest:RepeatStep">
		<tr>
			<td>Test Step</td>
			<td/>
			<td>Repeat Step 
				<xsl:value-of select="@ebTest:stepNumber"/>
				<xsl:text> , </xsl:text>
				<xsl:if test="@ebTest:repeatTimes">
					<xsl:value-of select="@ebTest:repeatTimes"/>
					<xsl:text> times </xsl:text>
				</xsl:if>
			</td>
			<td/>
			<td/>
			<td/>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:PutMessage">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@ebTest:description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
			</td>
			<td/>
			<td width="50%">
				<xsl:apply-templates select="ebTest:MessageDeclaration"/>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:SetPayload|ebTest:DSign"/>
	</xsl:template>
	<xsl:template match="ebTest:MessageDeclaration">
		<xsl:apply-templates mode="xmlverb"/>
	</xsl:template>
	<xsl:template match="ebTest:Filter">
		<xsl:value-of select="text()"/>
	</xsl:template>
	<xsl:template match="ebTest:SetPayload">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@ebTest:description"/>
			</td>
			<td/>
			<td> SetPayload(
				<xsl:value-of select="local-name()"/>
				<xsl:if test="@contentId">
					<xsl:text disable-output-escaping="no"> Content-ID="</xsl:text>
					<xsl:value-of select="@contentId" disable-output-escaping="no"/>
					<xsl:text disable-output-escaping="no"> "</xsl:text>
				</xsl:if>
				<xsl:if test="@contentLocation">
					<xsl:text disable-output-escaping="no"> Content-Location="</xsl:text>
					<xsl:value-of select="@contentLocation" disable-output-escaping="no"/>
					<xsl:text disable-output-escaping="no"> "</xsl:text>
				</xsl:if>
				<xsl:if test="@contentType">
					<xsl:text disable-output-escaping="no"> Content-Type="</xsl:text>
					<xsl:value-of select="@contentType" disable-output-escaping="no"/>
					<xsl:text disable-output-escaping="no"> "</xsl:text>
				</xsl:if>
				<xsl:apply-templates/>
)
			</td>
			<td/>
			<td width="50%">
				<xsl:apply-templates select="ebTest:Declaration"/>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:DSign">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@ebTest:description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
			</td>
			<td/>
			<td width="50%">
				<xsl:apply-templates select="./*" mode="xmlverb"/>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:GetMessage">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@ebTest:description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
				<xsl:if test="@ebTest:asyncronous='false'">
					<xsl:text> asycronous="</xsl:text>
					<xsl:value-of select="@ebTest:asyncronous"/>
					<xsl:text>" </xsl:text>
				</xsl:if>
				<xsl:if test="@ebTest:testStepContext">
					<xsl:text> testStepContext="</xsl:text>
					<xsl:value-of select="@ebTest:testStepContext"/>
					<xsl:text>" </xsl:text>
				</xsl:if>
				<xsl:if test="@ebTest:getMultipe='true'">
					<xsl:text> getMultiple="</xsl:text>
					<xsl:value-of select="@ebTest:getMultiple"/>
					<xsl:text>" </xsl:text>
				</xsl:if>
			</td>
			<td/>
			<td width="50%">
				<xsl:apply-templates select="ebTest:Content-ID|ebTest:Content-Location|ebTest:Index"/>
				<xsl:apply-templates select="ebTest:Filter"/>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:TestPreCondition|ebTest:TestAssertion|ebTest:GetPayload"/>
	</xsl:template>
	<xsl:template match="ebTest:GetPayload">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@ebTest:description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
				<xsl:apply-templates select="ebTest:Index|ebTest:Content-ID|ebTest:Content-Location"/>
				<xsl:value-of select="text()"/>
				<br/>
			</td>
			<td/>
			<td width="50%"/>
		</tr>
		<xsl:apply-templates select="ebTest:TestPreCondition|ebTest:TestAssertion"/>
	</xsl:template>
	<xsl:template match="ebTest:TestPreCondition">
		<tr bgcolor="BBBBBB">
			<td>Precondition</td>
			<xsl:apply-templates/>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:TestAssertion">
		<tr bgcolor="BBBBBB">
			<td>Assertion</td>
			<xsl:apply-templates/>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:ValidateContent|ebTest:VerifyContent">
		<td/>
		<td>
			<xsl:value-of select="../@ebTest:description"/>
		</td>
		<td/>
		<td>
			<xsl:value-of select="local-name()"/>
			<xsl:if test="@ebTest:contentType">
				 contentType=<xsl:value-of select="@ebTest:contentType"/>
			</xsl:if>
			<xsl:if test="@ebTest:schemaLocation">
				 schemaLocation=<xsl:value-of select="@ebTest:schemaLocation"/>
			</xsl:if>
		</td>
		<td/>
		<td width="50%">
			<xsl:value-of select="text()"/>
		</td>
	</xsl:template>
	<xsl:template match="ebTest:Template">
		<tr bgcolor="BBBBBB">
			<td colspan="6">
				<blockquote>
					<font color="666600">&lt;ebTest:</font>
					<font color="BB0000">Template</font>
					<font color="880000"> id=</font>
					<font color="000088">
						<b>"<xsl:value-of select="@ebTest:id"/>"</b>
					</font>&gt;
			<blockquote>
						<font color="666600">&lt;ebTest:</font>
						<font color="BB0000">FileName&gt;</font>
						<xsl:element name="a">
							<xsl:attribute name="href">templates/<xsl:value-of select="ebTest:FileName"/></xsl:attribute>
							<xsl:value-of select="ebTest:FileName"/>
						</xsl:element>
						<font color="666600">&lt;/ebTest:</font>
						<font color="BB0000">FileName&gt;</font>
					</blockquote>
					<font color="666600">&lt;/ebTest:</font>
					<font color="BB0000">Template</font>
				</blockquote>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:MimeHeader">
		<xsl:choose>
			<xsl:when test="count(preceding-sibling::*) > 0">
				<xsl:text> and /@</xsl:text>
				<xsl:value-of select="."/>= 
				</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test=". = 'MIMEMessageContent-Type'">
						<xsl:text>../@Content-Type = '</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'MIMEMessageStart'">
						<xsl:text>../@start = '</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>/@</xsl:text>
						<xsl:value-of select="."/>= 
				</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="ebTest:MimeHeaderValue">
		<xsl:text>'</xsl:text>
		<xsl:value-of select="."/>
		<xsl:text>'</xsl:text>
	</xsl:template>
	<xsl:template match="ebTest:FileURI">
		<xsl:text/>		
		fileURI = '<xsl:value-of select="."/>'
	</xsl:template>
	<xsl:template match="ebTest:payloadRef">
		<xsl:text/>
		payloadRef = '<xsl:value-of select="."/>'
	</xsl:template>
	<xsl:template match="ebTest:Content-ID">
		<xsl:choose>
			<xsl:when test="parent::node()[name()='ebTest:SetPayload']">
				<xsl:text> Content-Id = '</xsl:text>
			</xsl:when>
			<xsl:when test="parent::node()[name()='ebTest:GetPayload']">
				<xsl:text> Content-Id = '</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="parent::node()[name()='ebTest:SetPayload']">
				<xsl:value-of select="."/>
				<xsl:text>' </xsl:text>
			</xsl:when>
			<xsl:when test="parent::node()[name()='ebTest:GetPayload']">
				<xsl:value-of select="."/>
				<xsl:text>'</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:text/>
	</xsl:template>
	<xsl:template match="ebTest:Content-Location">
		<xsl:choose>
			<xsl:when test="parent::node()[name()='ebTest:SetPayload']">
				<xsl:text> Content-Location = '</xsl:text>
			</xsl:when>
			<xsl:when test="parent::node()[name()='ebTest:GetPayload']">
				<xsl:text>Content-Location = '</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="parent::node()[name()='ebTest:SetPayload']">
				<xsl:value-of select="."/>
				<xsl:text>' </xsl:text>
			</xsl:when>
			<xsl:when test="parent::node()[name()='ebTest:GetPayload']">
				<xsl:value-of select="."/>
				<xsl:text>'</xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="ebTest:Index">
		<xsl:text>Index='</xsl:text>
		<xsl:value-of select="."/>
		<xsl:text>'</xsl:text>
	</xsl:template>
	<xsl:template match="ebTest:Signature">
		<xsl:text/>
		signature = <xsl:value-of select="."/>
	</xsl:template>
	<xsl:template match="ebTest:PayloadRef">
		<xsl:text disable-output-escaping="no"> payloadRef=" </xsl:text>
		<xsl:value-of select="."/>
		<xsl:text disable-output-escaping="no">"</xsl:text>
	</xsl:template>
	<xsl:template match="ebTest:FileRef">
		<xsl:text disable-output-escaping="no"> payloadRef="</xsl:text>
		<xsl:value-of select="."/>
		<xsl:text disable-output-escaping="no">" </xsl:text>
	</xsl:template>
</xsl:stylesheet>
